==> apache-apisix-ingress-controller-1.6.0-src.tgz: powered-by.md <==
---
title: Powered by Apache APISIX Ingress
---

<!--
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
-->

This page documents an alphabetical list of institutions that are using APISIX Ingress for research and production,
or providing commercial products including APISIX Ingress.

Users are encouraged to add themselves to this page, [issue](https://github.com/apache/apisix-ingress-controller/issues/501) and PR are welcomed.

1. <a href="https://www.aispeech.com/" rel="nofollow">AISpeech 思必驰</a>
1. <a href="https://cloud.tencent.com/" rel="nofollow">Tencent Cloud 腾讯云</a>
1. <a href="https://www.upyun.com/" rel="nofollow">UPYUN 又拍云</a>
1. <a href="https://www.kubegems.io/" rel="nofollow">KubeGems</a>
1. <a href="https://www.igetcool.com/" rel="nofollow">少年得到</a>
1. <a href="https://www.niimbot.com/" rel="nofollow">NIIMBOT 武汉精臣智慧标识科技有限公司</a>
1. <a href="https://www.xmfunny.com/" rel="nofollow">SoFunny 厦门真有趣</a>
1. <a href="https://zoom.us/" rel="nofollow">Zoom</a>
1. <a href="https://referencesystem.copernicus.eu/" rel="nofollow">European Copernicus Reference System Software</a>
1. <a href="https://www.jiakaobaodian.com/" rel="nofollow">Jiakaobaodian(驾考宝典)</a>
1. <a href="https://www.horizon.ai/" rel="nofollow">Horizon Robotics(地平线)</a>

==> apache-apisix-ingress-controller-1.7.0-src.tgz: powered-by.md <==
---
title: Powered by Apache APISIX Ingress
---

<!--
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
-->

This page documents an alphabetical list of institutions that are using APISIX Ingress for research and production,
or providing commercial products including APISIX Ingress.

Users are encouraged to add themselves to this page, [issue](https://github.com/apache/apisix-ingress-controller/issues/501) and PR are welcomed.

1. <a href="https://www.aispeech.com/" rel="nofollow">AISpeech 思必驰</a>
1. <a href="https://cloud.tencent.com/" rel="nofollow">Tencent Cloud 腾讯云</a>
1. <a href="https://www.upyun.com/" rel="nofollow">UPYUN 又拍云</a>
1. <a href="https://www.kubegems.io/" rel="nofollow">KubeGems</a>
1. <a href="https://www.igetcool.com/" rel="nofollow">少年得到</a>
1. <a href="https://www.niimbot.com/" rel="nofollow">NIIMBOT 武汉精臣智慧标识科技有限公司</a>
1. <a href="https://www.xmfunny.com/" rel="nofollow">SoFunny 厦门真有趣</a>
1. <a href="https://zoom.us/" rel="nofollow">Zoom</a>
1. <a href="https://referencesystem.copernicus.eu/" rel="nofollow">European Copernicus Reference System Software</a>
1. <a href="https://www.jiakaobaodian.com/" rel="nofollow">Jiakaobaodian(驾考宝典)</a>
1. <a href="https://www.horizon.ai/" rel="nofollow">Horizon Robotics(地平线)</a>
1. <a href="https://www.xiaopeng.com/" rel="nofollow">小鹏汽车</a>
1. <a href="https://laf.run/" rel="nofollow">Laf</a>
